Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(156)

Unified Diff: net/quic/quic_connection.cc

Issue 355573007: Land Recent QUIC Changes. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: added NET_EXPORT_PRIVATE for ContainsQuicTag Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/quic_config_test.cc ('k') | net/quic/quic_connection_stats.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quic_connection.cc
diff --git a/net/quic/quic_connection.cc b/net/quic/quic_connection.cc
index a977b3fdcdb8d13d50f70c0a40d27721ddff9dc2..fb12065ca9437259ce28934fe75f9d8957568abf 100644
--- a/net/quic/quic_connection.cc
+++ b/net/quic/quic_connection.cc
@@ -1573,8 +1573,8 @@ void QuicConnection::SendPing() {
if (retransmission_alarm_->IsSet()) {
return;
}
- if (version() <= QUIC_VERSION_17) {
- // TODO(rch): remove this when we remove version 17.
+ if (version() <= QUIC_VERSION_16) {
+ // TODO(rch): remove this when we remove version 15 and 16.
// This is a horrible hideous hack which we should not support.
IOVector data;
char c_data[] = "C";
« no previous file with comments | « net/quic/quic_config_test.cc ('k') | net/quic/quic_connection_stats.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698